@@ -5,7 +5,16 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+BEGIN {
+	our $VERSION = '0.21';
+	
+	if ($] >= 5.016) {
+		require XSLoader;
+		XSLoader::load("Const::XS", $VERSION);
+	} else {
+		require Const::XS::PP;
+	}
+}
 
 use base qw/Import::Export/;
 
@@ -17,8 +26,6 @@ our %EX = (
 	is_readonly => [qw/all/],
 );
 
-require XSLoader;
-XSLoader::load("Const::XS", $VERSION);
 
 1;
 
@@ -30,7 +37,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
